@@ -456,7 +456,7 @@
       (make-triple on
                    (triple-guard t)
                    (and provides? (triple-blocking? t))
-                   (triple-statement t))))
+                   (deep-clone (triple-statement t)))))
   (define (split-triple-on t)
     (let* ((on (triple-on t))
            (triggers (ast:trigger* on))
@@ -1080,13 +1080,6 @@ expressions explicit."
      (let* ((statement (.statement o))
             (statement (add-explicit-temporaries statement)))
        (clone o #:statement statement)))
-    (($ <defer>)
-     (let* ((statement (.statement o))
-            (split? (or (split-complex? statement) (add-temporary? statement))))
-       (if (not split?) o
-           (let* ((statement (split+add-temporaries statement))
-                  (statement (add-explicit-temporaries statement)))
-             (clone o #:statement statement)))))
     ((and ($ <compound>) (? ast:declarative?))
      (clone o #:elements (map add-explicit-temporaries (ast:statement* o))))
     (($ <compound>)
@@ -1134,15 +1127,6 @@ explitic temporaries."
   "Split && and || into an if with a simple expression.  Depends on the
 add-explicit-temporaries transformation for splitting argument lists."
 
-  (define (replace-argument o old new)
-    (define (replace o)
-      (if (eq? (.node o) (.node old)) new
-          o))
-    (let* ((arguments (ast:argument* o))
-           (arguments (map replace arguments))
-           (arguments (clone (.arguments o) #:elements arguments)))
-      (clone o #:arguments arguments)))
-
   (define* (split o #:key not-e)
     (let* ((expression (.expression o))
            (expression (simplify-expression expression))
@@ -1150,7 +1134,7 @@ add-explicit-temporaries transformation for splitting argument lists."
       (match expression
         ((and ($ <and>) (= .left left) (= .right right))
          (let* ((then (cond (not-e
-                             (.then o))
+                             (deep-clone (.then o)))
                             (else
                              (clone o #:expression right))))
                 (false (make <literal> #:value "false"))
@@ -1161,7 +1145,7 @@ add-explicit-temporaries transformation for splitting argument lists."
                              (clone o #:expression
                                     (clone not-e #:expression right)))
                             ((is-a? o <if>)
-                             (.else then))
+                             (deep-clone (.else then)))
                             (else
                              (clone o #:expression false))))
                 (simple (make <if> #:expression left
@@ -1182,7 +1166,7 @@ add-explicit-temporaries transformation for splitting argument lists."
                           (clone not-e #:expression left)))
                 (left (simplify-expression left))
                 (else (cond ((is-a? o <if>)
-                             (.else then))
+                             (deep-clone (.else then)))
                             (else
                              (clone o #:expression false))))
                 (simple (make <if> #:expression left
@@ -1194,7 +1178,7 @@ add-explicit-temporaries transformation for splitting argument lists."
         ((and ($ <or>) (= .left left) (= .right right))
          (let* ((true (make <literal> #:value "true"))
                 (then (cond ((is-a? o <if>)
-                             (.then o))
+                             (deep-clone (.then o)))
                             (else
                              (clone o #:expression true))))
                 (else (clone o #:expression right))
