@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2015, 2016, 2017, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2015, 2016, 2017, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2017, 2018 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
@@ -251,7 +251,7 @@
 (define-method (code:data* (o <top>))
   #f)
 
-(define (cs:om ast)
+(define (cs:normalize ast)
   (parameterize ((%normalize:short-circuit? code:short-circuit?))
     ((compose
       add-reply-port
@@ -270,7 +270,7 @@
 
   (code-util:foreign-conflict? root)
 
-  (let ((root (cs:om root)))
+  (let ((root (cs:normalize root)))
     (let ((generator (code-util:indenter (cute x:source root)))
           (file-name (code-util:root-file-name root dir ".cs")))
       (code-util:dump root generator #:file-name file-name))
