@@ -4,7 +4,7 @@
 ;;; Copyright © 2019, 2020 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2018, 2019, 2020 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2018, 2019, 2020 Paul Hoogendijk <paul@dezyne.org>
-;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -46,6 +46,8 @@
   #:use-module (dzn templates)
   #:use-module (dzn verify constraint)
 
+  #:declarative? #f
+
   #:export (%model-name
             makreel:.name
             makreel:enum-fields
@@ -55,7 +57,7 @@
             makreel:model->makreel
             makreel:model-name
             makreel:name
-            makreel:om
+            makreel:normalize
             makreel:reply-type-sort
             makreel:tick-names
             makreel:unticked-dotted-name
@@ -206,8 +208,8 @@
        (fold (lambda (field method o)
                (clone o field ((compose (tick-names- names) method) o)))
              o
-             (list #:types #:ports #:variables #:functions #:statement)
-             (list .types .ports .variables .functions .statement))))
+             (list #:types #:variables #:functions #:statement)
+             (list .types .variables .functions .statement))))
     (($ <var>) (clone o #:name ((compose (append-tick names) .name) o)))
     (($ <field-test>) (clone o #:variable.name ((compose (append-tick names) .variable.name) o)))
     (($ <formal>) (clone o #:name ((compose (append-tick names) .name) o)
@@ -435,7 +437,7 @@
     calls))
 
 (define (reachable-calls o)
-  ((ast:pure-funcq reachable-calls-unmemoized) (ast:parent o <root>) o))
+  ((ast:perfect-funcq reachable-calls-unmemoized) (ast:parent o <root>) o))
 
 (define-method (no-tail-call (o <call>))
   (not (.last? o)))
@@ -522,8 +524,7 @@
 (define-method (makreel:event-act (o <component>))
   (append
    (makreel:interface* o)
-   (ast:port* o)
-   (ast:port* (.behavior o))))
+   (ast:port* o)))
 
 (define-method (makreel:event-act-provides (o <port>))
   (or (ast:provides? o) '()))
@@ -679,7 +680,7 @@
 (define-method (members (o <ast>))
   (members (ast:parent o <model>)))
 
-(define-method (makreel:locals-unmemoized root (o <ast>))
+(define-method (makreel:locals (o <ast>))
   (if (is-a? o <behavior>) '()
       (let* ((p (.parent o)))
         (cond ((is-a? p <compound>)
@@ -691,11 +692,6 @@
               ((is-a? o <function>) ((compose ast:formal* .signature) o))
               (else (makreel:locals p))))))
 
-(define (makreel:locals o)
-  (let* ((model (ast:parent o <model>))
-         (root (ast:parent model <root>)))
-    ((ast:pure-funcq makreel:locals-unmemoized) (list root model) o)))
-
 (define-method (variables-in-scope (o <model>)) (members o))
 (define-method (variables-in-scope (o <ast>))
   (let ((stack (and (or (as o <function>)
@@ -998,8 +994,7 @@
       '()))
 
 (define-method (makreel:stack-destructor (o <ast>))
-  (let ((f (and (not (is-a? o <defer>))
-                (not (ast:parent o <defer>))
+  (let ((f (and (not (ast:parent o <defer>))
                 (or (is-a? o <function>)
                     (ast:parent o <function>))))
         (locals (makreel:locals o))
@@ -1084,7 +1079,7 @@
     (_
      #f)))
 
-(define (makreel:om ast)
+(define (makreel:normalize ast)
   (parameterize ((%normalize:short-circuit? makreel:short-circuit?))
     (let ((root ((compose
                   makreel:mark-tail-call
@@ -1112,7 +1107,7 @@
     (newline)))
 
 (define* (ast-> ast #:key dir model)
-  (let ((root (makreel:om ast))
+  (let ((root (makreel:normalize ast))
         (init (command-line:get 'init)))
     (if model (makreel:model->makreel root (makreel:get-model root model))
         (root-> root))
